function difference = rstar_finder(rstar_kappa);
global lambda rmin_kappa phi r_kappa

% The procedure returns the difference between the numerical solution of d_phi(r_min_kappa) 
% for a given rstar_kappa. Therefore it uses a backtracking procedure for reduced potential phi. 
% It starts from r_star_kappa and calculates phi back to r_min_kappa.


% Derivative of potential phi at r_star_kappa (see text below eqn. 3.42)
% d_phi is used as initial condition for the solver in the next step

d_phi_init              =       besselk(1, rstar_kappa) / besselk(0, rstar_kappa);


% Numerically solving the Poisson-Boltzmann eqn. (3.39)
% ode45 is a numercal solver for ordinary differential equations (ODE) 
% [-rstar_kappa -rmin_kappa] is the range for the solution (minus sign are neccessary to pretend a forward solution)
% [d_phi_init 1] initial conditions for the reduced potential (and its derivative) at r_star_kappa
% ode45 returns out = [d_phi phi] for each r_kappa 

[r_kappa out]           =       ode45('PB_nonlin', [-rstar_kappa -rmin_kappa], [d_phi_init 1]);


% Comparison of derivative of potential with electric field at surface polyion
% Derivative of potential is given in the first column of out, as out = [d_phi phi]

difference              =       out(end,1) - (2 * lambda / rmin_kappa)


% Return potential and r_kappa for plotting to calc_nu_eff.m, as global variable
% Reverse the direction of r_kappa

r_kappa                 =       -r_kappa;
phi                     =       out;